<?php
/**
 * @file
 * Drush integration for the onecall_api module.
 */


/**
 * Implements hook_drush_command().
 */
function onecall_api_drush_command() {
  return array(
   'onecall-credits' => array(
      'description' => dt('Display the OneCall credit usage.'),
    ),
  );
}

/**
 * Default callback for the `drush credits` command.
 */
function drush_onecall_api_onecall_credits() {
  try {
    // Query ComScore for the credit usage data.
    $credit_data = onecall_api__credit_data();

    drush_print (dt('Remaining @credits_remaining/@daily_allowance (@percentage_used% used).', array(
      '@credits_remaining' => $credit_data->{"remaining-credits"},
      '@daily_allowance' => $credit_data->{"daily-limit"},
      '@percentage_used' => $credit_data->{"percentage-used"},
    )));
  }
  catch (ONECALL_API_NOT_CONFIGURED_EXCEPTION $e) {
    drush_set_error(dt('OneCall API is not configured.'));
  }
  catch (ONECALL_API_INVALID_CREDENTIALS_EXCEPTION $e) {
    drush_set_error(dt('The OneCall API credentials are not valid.'));
  }
  catch (ONECALL_API_REQUEST_NETWORK_FAILURE_EXCEPTION $e) {
    drush_set_error(dt('OneCall API request is failing with a network/transport error.'));
  }
  catch (ONECALL_API_REQUEST_TIMED_OUT_EXCEPTION $e) {
    drush_set_error(dt('The OneCall API request is timing out.'));
  }
}
